@@ -12,11 +12,11 @@ sim_discrete_time <- function(dag, n_sim=NULL, t0_sort_dag=FALSE,
 
   if (!inherits(dag, "DAG")) {
     stop("'dag' must be a DAG object created using the empty_dag() and",
-         " node_td() functions.")
+         " node_td() functions.", call.=FALSE)
   }
   tx_nodes <- dag$tx_nodes
 
-  requireNamespace("data.table")
+  requireNamespace("data.table", quietly=TRUE)
 
   if (check_inputs) {
     check_inputs_sim_discrete_time(n_sim=n_sim, dag=dag,
